==> ingdao-0.0.6.tar.gz: example/datasync/lib/datalayer/data_factory.dart <==

import '../appsetting.dart';
import 'package:ingdao/ingdao.dart';
import 'package:ingdao/dataflow/model/dfwebmodel.dart';
import 'package:ingdao/dataflow/repository/dfwebrepository.dart';
import 'package:ingdao/dataflow/repository/dfsyncrepository.dart';
import 'package:ingdao/dataflow/model/dfdbmodel.dart';
import 'package:ingdao/dataflow/model/dfsyncmodel.dart';
import 'package:ingdao/dataflow/repository/dfdbrepository.dart';
import 'entity/tanktimesheet/tanktimesheet.dart';
import 'entity/tanktimesheet/tanktimesheetweb.dart';

const REPO_NAME_SQLITEDB = "sqlitedb";
const REPO_NAME_WEB = "web";
const REPO_NAME_ONLINE_SYNC = "onlinesync";

enum RepositoryType {
  sqlitedb,
  web,
  onlinesync
}

extension RepositoryTypeExtension on RepositoryType {

  String get name {
    switch (this) {
      case RepositoryType.sqlitedb:
        return REPO_NAME_SQLITEDB;
      case RepositoryType.web:
        return REPO_NAME_WEB;
      case RepositoryType.onlinesync:
        return REPO_NAME_ONLINE_SYNC;                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DataFactory {

  AppSetting appSetting = AppSetting();

  DataFactory._();
  static final instance = DataFactory._();

  Future<DfFactory> getManipulator(RepositoryType type) async {
    DfFactory dfFactory = DfFactory();

      //Web
      SslPinningCri sslPinningCri;//SslPinningCri(shakeys: appSetting.sslPinningFingerPrints, shatype: SslPinningCriShaType.SHA256);
      DfWebModel modelWeb = DfWebModel(name: RepositoryType.web.name, 
                                      encrypt: appSetting.dataEncrypt, 
                                      entities: [TankTimesheetWeb()], 
                                      serverUrl: appSetting.serverUrl, 
                                      commonHeaders: DfWebModel.formJsonHeader(authToken: appSetting.token), 
                                      sslPinningCri: sslPinningCri);

      DfWebRepository repWeb = DfWebRepository(model: modelWeb); 
      dfFactory.registerRepository(RepositoryType.web.name, repWeb);

      //Database
      DfDbModel modelDb = DfDbModel(name: RepositoryType.sqlitedb.name, 
                                    dbName: appSetting.dbName, 
                                    encrypt: appSetting.dataEncrypt, 
                                    entities: [TankTimesheet()]);
      DfDbRepository repDb = DfDbRepository(model: modelDb);
      dfFactory.registerRepository(RepositoryType.sqlitedb.name, repDb);

      //Online Sync
      DfSyncModel modelSync = DfSyncModel(name: RepositoryType.onlinesync.name, 
                                          retryIntervalInSecond: 15 * 60, 
                                          dbRepository: repDb, 
                                          webRepository: repWeb);
      DfSyncRepository repSync = DfSyncRepository(model: modelSync);                                          
      dfFactory.registerRepository(RepositoryType.onlinesync.name, repSync);

      //Activate
      await dfFactory.activateRepository(type.name);  
      return dfFactory;
  }
}

==> ingdao-0.0.19.tar.gz: example/datasync/lib/datalayer/data_factory.dart <==

import '../appsetting.dart';
import 'package:ingdao/ingdao.dart';
import 'package:ingdao/dataflow/model/dfwebmodel.dart';
import 'package:ingdao/dataflow/repository/dfwebrepository.dart';
import 'package:ingdao/dataflow/repository/dfsyncrepository.dart';
import 'package:ingdao/dataflow/model/dfdbmodel.dart';
import 'package:ingdao/dataflow/model/dfsyncmodel.dart';
import 'package:ingdao/dataflow/repository/dfdbrepository.dart';
import 'entity/tanktimesheet/tanktimesheet.dart';
import 'entity/tanktimesheet/tanktimesheetweb.dart';

const REPO_NAME_SQLITEDB = "sqlitedb";
const REPO_NAME_WEB = "web";
const REPO_NAME_ONLINE_SYNC = "onlinesync";

enum RepositoryType {
  sqlitedb,
  web,
  onlinesync
}

extension RepositoryTypeExtension on RepositoryType {

  String get name {
    switch (this) {
      case RepositoryType.sqlitedb:
        return REPO_NAME_SQLITEDB;
      case RepositoryType.web:
        return REPO_NAME_WEB;
      case RepositoryType.onlinesync:
        return REPO_NAME_ONLINE_SYNC;                
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

class DataFactory {
  DataFactory._();
  static final instance = DataFactory._();

  Future<DfFactory> getManipulator(RepositoryType type) async {
    DfFactory dfFactory = DfFactory();

      //Web
      SslPinningCri sslPinningCri;//SslPinningCri(shakeys: appSetting.sslPinningFingerPrints, shatype: SslPinningCriShaType.SHA256);
      DfWebModel modelWeb = DfWebModel(name: RepositoryType.web.name, 
                                      encrypt: AppSetting.dataEncrypt, 
                                      entities: [TankTimesheetWeb()], 
                                      serverUrl: AppSetting.serverUrl, 
                                      commonHeaders: DfWebModel.formJsonHeader(), 
                                      sslPinningCri: sslPinningCri);

      DfWebRepository repWeb = DfWebRepository(model: modelWeb); 
      dfFactory.registerRepository(RepositoryType.web.name, repWeb);

      //Database
      DfDbModel modelDb = DfDbModel(name: RepositoryType.sqlitedb.name, 
                                    dbName: AppSetting.dbName, 
                                    encrypt: AppSetting.dataEncrypt, 
                                    entities: [TankTimesheet()]);
      DfDbRepository repDb = DfDbRepository(model: modelDb);
      dfFactory.registerRepository(RepositoryType.sqlitedb.name, repDb);

      //Online Sync
      DfSyncModel modelSync = DfSyncModel(name: RepositoryType.onlinesync.name, 
                                          retryIntervalInSecond: 15 * 60, 
                                          dbRepository: repDb, 
                                          webRepository: repWeb);
      DfSyncRepository repSync = DfSyncRepository(model: modelSync);                                          
      dfFactory.registerRepository(RepositoryType.onlinesync.name, repSync);

      //Activate
      await dfFactory.activateRepository(type.name);  
      return dfFactory;
  }
}
